normaliz: Computations in affine monoids, vector configurations, lattice polytopes, and rational cones
======================================================================================================

Description
-----------

Normaliz is a tool for computations in affine monoids, vector
configurations, lattice polytopes, and rational cones.

For more details see http://www.mathematik.uni-osnabrueck.de/normaliz/

License
-------

-  GPL v3


Upstream Contact
----------------

-  normaliz@uos.de
-  Winfried Bruns <wbruns@uos.de>
-  Christof Söger <csoeger@uos.de>
-  see also https://www.normaliz.uni-osnabrueck.de/home/contact/

   and https://github.com/Normaliz

Special Update/Build Instructions
---------------------------------

-  The spkg currently disables features that require packages SCIP and
   CoCoA, for which we don't have packages (yet).
